@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/usr/bin/python3 -tt
 # -*- coding: utf-8 -*-
 # (keep hashbang line for `make install`)
 
@@ -36,7 +36,7 @@ import gnupg # Provided e.g. by `pip install python-gnupg` (try with `pip2`/`pip
 import pygit2 as git
 import requests
 
-VERSION = '1.0.2'
+VERSION = '1.0.3'
 
 
 class GitArgumentParser(argparse.ArgumentParser):
@@ -117,6 +117,17 @@ class DefaultTrueIfPresent(argparse.Action):
     def convert_default(cls, value):
         return bool(distutils.util.strtobool(value))
 
+
+server_aliases = {
+    "gitta": "gitta.zeitgitter.net",
+    "diversity": "diversity.zeitgitter.net"
+}
+
+
+def expanded_aliases():
+    return ', '.join(map(lambda t: "%s → %s" % t, server_aliases.items()))
+
+
 def get_args():
     """Parse command line and git config parameters"""
     parser = GitArgumentParser(
@@ -125,7 +136,7 @@ def get_args():
                     independent GIT timestampers.""",
         epilog="""`--tag` takes precedence over `--branch`.
             When in doubt, use `--tag` for single/rare timestamping,
-            and `--branch` for reqular timestamping.
+            and `--branch` for frequent timestamping.
             `bool` values can be specified as true/false/yes/no/0/1.
             Arguments with optional `bool` options default to true if
             the argument is present, false if absent.""")
@@ -144,12 +155,15 @@ def get_args():
                gitopt='timestamp.branch',
                help="""Create a timestamped commit in branch BRANCH,
                    with identical contents as the specified commit.
-                   Default name derived from servername plus `-timestamps`""")
+                   Default name derived from servername, appending
+                   `-timestamps`, and, possibly, by the effects of
+                   `--append-branch-name`.""")
     parser.add('--server',
                default='https://gitta.zeitgitter.net',
                gitopt='timestamp.server',
-               help="""Zeitgitter server to obtain timestamp from
-                   ('https://' is optional)""")
+               help="""Zeitgitter server to obtain timestamp from. 'https://'
+                   is optional. The following aliases are supported: """
+                   + expanded_aliases())
     parser.add('--append-branch-name',
                default=True,
                action=DefaultTrueIfPresent,
@@ -186,12 +200,14 @@ def get_args():
                help="""Which commit-ish to timestamp. Must be a branch name
                        for branch timestamps with `--append-branch-name`""")
     arg = parser.parse_args()
-    if ':' not in arg.server:
-        arg.server = 'https://' + arg.server
     if arg.enable == False:
         sys.exit("Timestamping explicitely disabled")
     if arg.require_enable and arg.enable != True:
         sys.exit("Timestamping not explicitely enabled")
+    if arg.server in server_aliases:
+        arg.server = server_aliases[arg.server]
+    if ':' not in arg.server:
+        arg.server = 'https://' + arg.server
     if arg.tag is None and arg.branch is None:
         # Automatically derive branch name
         # Split URL on '.' or '/'
@@ -218,7 +234,8 @@ def validate_key_and_import(text, args):
     info = gpg.scan_keys(f.name)
     os.unlink(f.name)
     if len(info) != 1 or info[0]['type'] != 'pub' or len(info[0]['uids']) == 0:
-        sys.exit("Invalid key returned")
+        sys.exit("Invalid key returned\n"
+                 "Maybe not a Zeitgitter server or ~/.gnupg permission problem")
     res = gpg.import_keys(text)
     if res.count == 1 and not args.quiet:
         print("Imported new key %s: %s" %
@@ -471,23 +488,37 @@ def valid_name(name):
 
 def append_branch_name(repo, commit_name, branch_name):
     """Appends current branch name if not `master`"""
+    explanation = "for (implicit) options `--branch and --append-branch-name`"
     if commit_name == 'HEAD':
         try:
             comref = repo.lookup_reference(commit_name)
-            comname = comref.target # Branch HEAD points to
+            comname = comref.target
         except git.InvalidSpecError:
-            sys.exit("Invalid HEAD")
-        if comname.startswith('refs/heads/'):
+            # 1. If HEAD or it's target is invalid, we end up here
+            sys.exit("Invalid HEAD " + explanation)
+        # Two more options remain:
+        # 2. If HEAD points to a branch, then we now have its name (a `str`
+        #    starting with 'refs/heads/') and can proceed;
+        # 3. if it is detached, it points to a commit (a `Oid`) and we fail;
+        # 4. there might be some other cases, which should fail as well.
+        # To be able to test for case 2, we convert `comname` to `str`.
+        if str(comname).startswith('refs/heads/'):
             comname = comname[len('refs/heads/'):]
         else:
-            sys.exit("HEAD must point to branch, not %s" % comname)
+            sys.exit(("HEAD must point to branch, not %s " + explanation)
+                    % comname)
     else:
+        # 5. Explicit and non-HEAD commit given; check for branch name only: proceed;
         try:
             comref = repo.lookup_reference('refs/heads/' + commit_name)
             comname = commit_name # Branch name itself
         except (KeyError, git.InvalidSpecError):
-            sys.exit("%s must be a branch name" % commit_name)
+            # 6. Explicit commit given, but it's neither HEAD nor tail^H^H^H^H
+            # a branch: fail
+            sys.exit(("%s must be a branch name " + explanation)
+                    % commit_name)
 
+    # Now that we know which branch to timestamp (to), construct it.
     if comname == 'master':
         return branch_name
     else:
@@ -495,9 +526,10 @@ def append_branch_name(repo, commit_name, branch_name):
         if valid_name(extended_name):
             return extended_name
         else:
-            sys.exit("Branch name %s is not valid for timestamping\n"
+            sys.exit(("Branch name %s is not valid for timestamping\n"
                     "(constructed from base timestamp branch %s and "
-                    "source branch %s)" % (extended_name, branch_name, comname))
+                    "source branch %s)\n" + explanation)
+                    % (extended_name, branch_name, comname))
 
 
 def timestamp_branch(repo, keyid, name, args):
